package com.lantone.qc.kernel.structure.ai;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.CRFServiceClient;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Annotation;
import com.lantone.qc.pub.model.label.ChiefLabel;
import com.lantone.qc.pub.model.vo.CRFVo;
import com.lantone.qc.pub.util.StringUtil;

import java.util.Arrays;
import java.util.List;

/**
 * @ClassName : InHospitalDoc
 * @Description :
 * @Author : 楼辉荣
 * @Date: 2020-03-03 18:58
 */
public class BeHospitalizedAI extends QCCatalogue {
    /**
     * FirstCourseRecord_cx[病历首程]
     * PastFamily_cx[既往史家族史]
     * PersonalHistory_cx[个人史(月经史、婚育史)]
     * HPIForCX_cx[主诉、现病史、专科检查]
     * GeneralVital_cx[一般体格检查]
     * chief_present[邵逸夫医院主诉现病史]
     */
    public static List<String> medicalTextType = Arrays.asList("FirstCourseRecord_cx", "PastFamily_cx", "PersonalHistory_cx", "HPIForCX_cx",
            "GeneralVital_cx", "chief_present");
    public void medrec(InputInfo inputInfo,CRFServiceClient crfServiceClient){
        JSONArray crfContent = new JSONArray();
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        String chief_text = beHospitalizedDoc.getChiefLabel().getText();
        String Personal_text = beHospitalizedDoc.getPersonalLabel().getText();
        String family_text = beHospitalizedDoc.getFamilyLabel().getText();
        String past_text = beHospitalizedDoc.getPastLabel().getText();
        String present_text = beHospitalizedDoc.getPresentLabel().getText();
        //月经史
        String menstrual_text = beHospitalizedDoc.getMenstrualLabel().getText();
        //婚育史
        String marital_text = beHospitalizedDoc.getMaritalLabel().getText();
        //存放主诉、现病史
        putContent(crfContent,medicalTextType.get(3), chief_text,Content.chief);
        putContent(crfContent,medicalTextType.get(3), present_text,Content.present);
        //存放既往史、家族史
        putContent(crfContent,medicalTextType.get(3), past_text,Content.past);
        putContent(crfContent,medicalTextType.get(3), family_text,Content.family);
        //存放个人史、月经史、婚育史
        putContent(crfContent,medicalTextType.get(3), Personal_text,Content.personal);
        putContent(crfContent,medicalTextType.get(3), menstrual_text,Content.menses);
        putContent(crfContent,medicalTextType.get(3), marital_text,Content.marriage);
        //存储CRF完整所需结构数据
        CRFVo crfVo = new CRFVo();
        crfVo.setData(crfContent);
        //获取CRF模型返回数据
        JSONArray data = getAnnotation(crfServiceClient, crfVo).getData();
        JSONObject midData = getOutputs(data);



    }
    public void putContent(JSONArray crfContent, String medicalTextType, String text,String sign){
        String move_text = this.moveSpecialSymbols(text);
        if (StringUtil.isEmpty(move_text)) {
            return;
        }
        JSONObject detailContent = new JSONObject();
        detailContent.put("medical_text_type", medicalTextType);
        detailContent.put("content", move_text);
        detailContent.put("detail_title", sign);
        crfContent.add(detailContent);
    }
    private Annotation getAnnotation(CRFServiceClient crfServiceClient, CRFVo crfVo) {

        Annotation annotation = new Annotation();
        try {
            String annotation_str = crfServiceClient.getAnnotation(crfVo);
            annotation = JSON.parseObject(annotation_str, Annotation.class);
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            return annotation;
        }
    }

    /**
     * 获取CRF模型输出并处理
     *
     * @param data
     * @return
     */
    public JSONObject getOutputs(JSONArray data) {
        JSONObject midData = new JSONObject();
        for (int i = 0; i < data.size(); i++) {
            JSONObject detailContent = data.getJSONObject(i);
            String detail_title = detailContent.getString("detail_title");
            if (StringUtil.isNotEmpty(detail_title) && midData.get(detail_title) == null) {
                midData.put(detail_title, detailContent);
            }
        }
        return midData;
    }
    //文本去除\r\n\t特殊符号
    public String moveSpecialSymbols(String content){
        if (StringUtil.isEmpty(content)){
            return "";
        }
        return content.replaceAll("\\r\\n|/r/n", "\r\n")
                .replaceAll("\\t", "\t").trim();
    }
}